@@ -37,7 +37,7 @@ test_that("as.LDARep", {
   # ids not fitting data.frame
   expect_error(as.LDARep(lda = list("1" = lda), job = as.data.frame(c(job.id = 2, getParam(lda)))))
   # names lda not integerish (only a warning!!)
-  expect_warning(as.LDARep(lda = list("abc" = lda)))
+  expect_error(as.LDARep(lda = list("abc" = lda)))
   # no param in lda to interprete and no job given
   expect_error(as.LDARep(lda = list(ldawoparam)))
   # duplicated names
@@ -70,6 +70,8 @@ test_that("is.LDARep", {
   nores = res
   nores$jobs$job.id = as.character(getJob(res)$job.id)
   expect_false(is.LDARep(nores, verbose = TRUE))
+  nores$jobs$job.id = as.numeric(getJob(res)$job.id)
+  expect_false(is.LDARep(nores, verbose = TRUE))
   nores$jobs = rbind(getJob(res), getJob(res))
   expect_false(is.LDARep(nores, verbose = TRUE))
   nores$jobs = as.data.frame(getJob(res))
@@ -81,6 +83,9 @@ test_that("is.LDARep", {
   expect_false(is.LDARep(nores, verbose = TRUE))
   nores$lda = unlist(getLDA(res))
   expect_false(is.LDARep(nores, verbose = TRUE))
+  nores$lda = getLDA(res)
+  nores$lda[[1]]$param = NULL
+  expect_false(is.LDARep(nores, verbose = TRUE))
 
   # general
   nores = res
@@ -94,8 +99,8 @@ test_that("is.LDARep", {
   expect_false(is.LDARep(nores, verbose = TRUE))
 
   # repeated num.iterations
-  expect_error(LDARep(docs = reuters_docs,
-    vocab = reuters_vocab, n = 1, num.iterations = 10, num.iterations = 5))
+  expect_error(suppressWarnings(LDARep(docs = reuters_docs,
+    vocab = reuters_vocab, n = 1, num.iterations = 10, num.iterations = 5)))
   expect_warning(res0 <- LDARep(docs = reuters_docs, K = 2,
     vocab = reuters_vocab, n = 1, num.iterations = 10, num.iterations = 5))
   expect_equal(getNum.iterations(getLDA(res0)), 5)
